@@ -1,6 +1,9 @@
 package Net::Braintree::WebhookNotification::Kind;
 use strict;
 
+use constant PartnerMerchantConnected => "partner_merchant_connected";
+use constant PartnerMerchantDisconnected => "partner_merchant_disconnected";
+use constant PartnerMerchantDeclined => "partner_merchant_declined";
 use constant SubscriptionCanceled => "subscription_canceled";
 use constant SubscriptionChargedSuccessfully => "subscription_charged_successfully";
 use constant SubscriptionChargedUnsuccessfully => "subscription_charged_unsuccessfully";
@@ -13,6 +16,9 @@ use constant SubMerchantAccountDeclined => "sub_merchant_account_declined";
 use constant TransactionDisbursed => "transaction_disbursed";
 
 use constant All => (
+  PartnerMerchantConnected,
+  PartnerMerchantDisconnected,
+  PartnerMerchantDeclined,
   SubscriptionCanceled,
   SubscriptionChargedSuccessfully,
   SubscriptionChargedUnsuccessfully,
